==> korweblog-1.6.0.tar.gz: korweblog-1.6.0/include/sblock/tb.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

if (!defined("LOAD_MODULE"))
	die ("You can not access this file directly...");
# last 5 trackback entry

unset($VAR);
$ret = SqlQuery("SELECT * FROM T_Trackback ORDER BY time DESC LIMIT 5");
if (mysql_num_rows($ret)) {
	$VAR['Heading'] = _TB_BLOCK;
   $VAR['Content'] = '';
	while ($A = mysql_fetch_array($ret)) {
		$VAR['Content'] .= "$CONF[dotchar]<a href=\"$CONF[G_URL]/tb.php?story={$A['Rid']}&amp;x=1#{$A['tid']}\">".
         htmlspecialchars($A['title']) ."</a><br />\n";
	}
   $VAR['Display'] =& $align;
	KWL_DrawBlock($VAR);
	mysql_free_result($ret);
}
?>

==> korweblog-1.6.1.tar.gz: korweblog-1.6.1/include/sblock/tb.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

if (!defined("LOAD_MODULE"))
	die ("You can not access this file directly...");
# last 5 trackback entry

unset($VAR);
$ret = SqlQuery("SELECT * FROM T_Trackback ORDER BY time DESC LIMIT 5");
if (mysql_num_rows($ret)) {
	$VAR['Heading'] = _TB_BLOCK;
   $VAR['Content'] = '';
   $script = $CONF['tbmsg_show'] ? "stories.php?" : "tb.php?x=1&amp;";
	while ($A = mysql_fetch_array($ret)) {
		$VAR['Content'] .= "$CONF[dotchar]<a href=\"$CONF[G_URL]/$script". "story={$A['Rid']}#{$A['tid']}\">".
         htmlspecialchars($A['title']) ."</a><br />\n";
	}
   $VAR['Display'] =& $align;
	KWL_DrawBlock($VAR);
	mysql_free_result($ret);
}
?>
